@@ -75,7 +75,7 @@ PropertyWatcher.prototype.propertyChanged = function(value) {
             if (this.sender.itemData(value)===PropertyEditor.varies) {
                 return;
             }
-            this.propertyEditor.propertyChanged(this.propertyType,
+            this.propertyEditor.propertyChanged(this.propertyType, 
                                                 this.sender.itemData(value));
             return;
         }
@@ -1058,6 +1058,10 @@ PropertyEditorImpl.prototype.initControls = function(propertyTypeId, onlyChanges
 PropertyEditorImpl.prototype.initNumberControls = function(objectName, propertyTypeId, onlyChanges, control, index) {
     var document = EAction.getDocument();
 
+    if (isNull(document)) {
+        return;
+    }
+
     var value = this.getAdjustedPropertyValue(propertyTypeId);
     if (isNumber(index)) {
         value = value[index];
@@ -1338,6 +1342,7 @@ PropertyEditorImpl.prototype.initChoiceControls = function(
                 var pw = new PropertyWatcher(this, control, propertyTypeId);
                 if (RSettings.getQtVersion() >= 0x060000) {
                     control.textActivated.connect(pw, pw.propertyChanged);
+                    //control.currentTextChanged.connect(pw, pw.propertyChanged);
                 }
                 else {
                     control['activated(QString)'].connect(pw, pw.propertyChanged);
@@ -1347,6 +1352,7 @@ PropertyEditorImpl.prototype.initChoiceControls = function(
                 var pw = new PropertyWatcher(this, control, propertyTypeId);
                 if (RSettings.getQtVersion() >= 0x060000) {
                     control.activated.connect(pw, pw.propertyChanged);
+                    //control.currentIndexChanged.connect(pw, pw.propertyChanged);
                 }
                 else {
                     control['activated(int)'].connect(pw, pw.propertyChanged);
@@ -1356,14 +1362,20 @@ PropertyEditorImpl.prototype.initChoiceControls = function(
 
     }
 
+    //var signalsBlocked;
+
     if (propertyTypeId.getId()===REntity.PropertyLayer.getId()) {
         WidgetFactory.initLayerCombo(control, EAction.getDocument());
     }
     else if (propertyTypeId.getId()===RTextEntity.PropertyHAlign.getId()) {
+        //signalsBlocked = control.blockSignals(true);
         WidgetFactory.initHAlignCombo(control);
+        //control.blockSignals(signalsBlocked);
     }
     else if (propertyTypeId.getId()===RTextEntity.PropertyVAlign.getId()) {
+        //signalsBlocked = control.blockSignals(true);
         WidgetFactory.initVAlignCombo(control);
+        //control.blockSignals(signalsBlocked);
     }
     else if (propertyTypeId.getId()===RDimensionEntity.PropertyDimlunit.getId()) {
         WidgetFactory.initDimlunitCombo(control);
@@ -1530,7 +1542,7 @@ PropertyEditorImpl.prototype.filterChanged = function() {
         entityTypeFilter = RS.EntityAll;
     }
 
-    this.updateFromDocument(doc, false, entityTypeFilter, true);
+    this.updateFromDocumentNow(doc, false, entityTypeFilter, true);
 };
 
 /**
@@ -1548,7 +1560,7 @@ PropertyEditorImpl.prototype.requestAllProperties = function() {
         entityTypeFilter = RS.EntityAll;
     }
 
-    this.updateFromDocument(doc, false, entityTypeFilter, true, true);
+    this.updateFromDocumentNow(doc, false, entityTypeFilter, true, true);
 };
 
 PropertyEditorImpl.prototype.getAdjustedPropertyValue = function(propertyTypeId) {
@@ -1645,7 +1657,7 @@ PropertyEditorImpl.prototype.addCustomProperty = function() {
     var valueEdit = dialog.findChild("Value");
 
     if (!dialog.exec()) {
-        destr(dialog);
+        destrDialog(dialog);
         EAction.activateMainWindow();
         return;
     }
@@ -1657,7 +1669,7 @@ PropertyEditorImpl.prototype.addCustomProperty = function() {
     this.propertyChanged(new RPropertyTypeId(RSettings.getAppId(), name), value, this.getEntityTypeFilter());
     this.onlyChangesOverride = false;
 
-    destr(dialog);
+    destrDialog(dialog);
     EAction.activateMainWindow();
 };
 
@@ -1687,6 +1699,18 @@ PropertyEditor.initPreferences = function(pageWidget, calledByPrefDialog, docume
     w.addItem("7 (1/128)", 7);
     w.addItem("8 (1/256)", 8);
     w.currentIndex = 8;
+
+    // hide Qt 6 only options:
+    if (RSettings.getQtVersion() < 0x060000) {
+        var widgets = ["LazyUpdate", "LazyUpdateDelay_Label", "LazyUpdateDelay"];
+        for (var i=0; i<widgets.length; i++) {
+            w = pageWidget.findChild(widgets[i]);
+            if (!isNull(w)) {
+                w.visible = false;
+            }
+        }
+
+    }
 };
 
 PropertyEditor.applyPreferences = function(doc, mdiChild) {
